@@ -1,7 +1,7 @@
 exams_skeleton <- exams.skeleton <- function(dir = ".",
   type = c("num", "schoice", "mchoice", "string", "cloze"),
   writer = c("exams2html", "exams2pdf", "exams2moodle", "exams2qti12", "exams2qti21", "exams2arsnova", "exams2nops"),
-  markup = "latex", absolute = FALSE, encoding = "")
+  markup = "markdown", absolute = FALSE, encoding = "")
 {
   ## match available types/writers
   type <- as.vector(sapply(type, match.arg,
@@ -25,10 +25,10 @@ exams_skeleton <- exams.skeleton <- function(dir = ".",
   
   ## select exercises for demo script and all available exercises
   exrc <- c(
-    "num"     = "tstat",
-    "schoice" = "tstat2",
+    "num"     = "deriv",
+    "schoice" = "swisscapital",
     "mchoice" = "boxplots",
-    "cloze"   = "boxhist",
+    "cloze"   = "lm",
     "string"  = "function"
   )
   exrc <- exrc[type]
@@ -122,12 +122,15 @@ exams_skeleton <- exams.skeleton <- function(dir = ".",
     '',
     sprintf('## in the following the exercises in %s (.Rnw) format are discussed',
       if(markup == "latex") "R/LaTeX" else "R/Markdown"),
+    '## for some more details see also http://www.R-exams.org/tutorials/first_steps/',
     '',
     '',
     '## inspect individual exercises -----------------------------------------------------',
     '',
-    '## simply turn a single exercise into a HTML file (shown in browser)',
+    '## simply turn a single exercise into a HTML file (shown in browser, using MathML)',
     sprintf('exams2html("%s")', exrc[1L]),
+    '## simply turn a single exercise into a HTML file (shown in browser, using MathJax)',
+    sprintf('exams2html("%s", converter = "pandoc-mathjax")', exrc[1L]),
     '## or a PDF file (shown in PDF viewer)',
     sprintf('exams2pdf("%s")', exrc[1L]),
     '',
@@ -137,47 +140,62 @@ exams_skeleton <- exams.skeleton <- function(dir = ".",
     '',
     '## types of exercises ---------------------------------------------------------------',
     '',
+    '## for an overview see also http://www.R-exams.org/templates/',
+    '',
     if(!("num" %in% type)) NULL else c(
     '## numeric exercises',
     'exams2html(c(',
-    '  "tstat.Rnw",      ## computation of t-statistic',
-    '  "dist.Rnw",       ## computation of Euclidean distance',
-    '  "regression.Rnw", ## prediction in simple linear regression',
-    '  "lagrange.Rnw"    ## optimization under constraint',
+    '  "deriv.Rnw",        ## product rule for derivatives',
+    '  "tstat.Rnw",        ## 1-sample t-test statistic',
+    '  "dist.Rnw",         ## distances and the Pythagorean theorem',
+    '  "regression.Rnw",   ## simple linear regression (by hand)',
+    '  "fruit.Rnw",        ## image-based systems of linear equations (numeric)',
+    '  "lagrange.Rnw",     ## method of Lagrange multipliers',
+    '  "currency8.Rnw"     ## convert currencies (UTF-8 encoding)',
     '))',
     ''),
     if(!("schoice" %in% type)) NULL else c(
-    '## single choice exercises',
+    '## single-choice exercises',
     'exams2html(c(',
-    '  "tstat2.Rnw", ## single-choice list of numeric tstat exercise (by hand)',
-    '  "dist3.Rnw"   ## single-choice list of numeric dist exercise (via num_to_schoice)',
+    '  "swisscapital.Rnw", ## knowledge quiz question about the Swiss capital',
+    '  "Rlogo.Rnw",        ## knowledge quiz question about the R logo',
+    '  "deriv2.Rnw",       ## product rule for derivatives (single-choice, via num_to_schoice)',
+    '  "tstat2.Rnw",       ## 1-sample t-test statistic (single-choice, by hand)',
+    '  "dist3.Rnw",        ## distances and the Pythagorean theorem (single-choice, via num_to_schoice)',
+    '  "fruit2.Rnw",       ## image-based systems of linear equations (single-choice, via num_to_schoice)',
+    '  "hessian.Rnw",      ## 2x2 Hessian matrix (single-choice)',
+    '  "logic.Rnw"         ## interpretation of logic gates (using TikZ)',
     '))',
     ''),
     if(!("mchoice" %in% type)) NULL else c(
-    '## multiple choice exercises',
+    '## multiple-choice exercises',
     'exams2html(c(',
-    '  "anova.Rnw",       ## interpret ANOVA results',
-    '  "boxplots.Rnw",    ## interpret parallel boxplots',
-    '  "scatterplot.Rnw", ## interpret scatterplot',
-    '  "ttest.Rnw",       ## 2-sample t-test',
-    '  "relfreq.Rnw",     ## table of relative frequencies',
-    '  "cholesky.Rnw"     ## Cholesky factorization',
+    '  "switzerland.Rnw",  ## knowledge quiz question about Switzerland',
+    '  "gaussmarkov.Rnw",  ## knowledge quiz question about Gauss-Markov assumptions',
+    '  "anova.Rnw",        ## 1-way analysis of variance',
+    '  "boxplots.Rnw",     ## interpretation of 2-sample boxplots',
+    '  "scatterplot.Rnw",  ## interpretation of a scatterplot',
+    '  "ttest.Rnw",        ## interpretation of 2-sample t test',
+    '  "relfreq.Rnw",      ## interpretation of relative frequency tables',
+    '  "cholesky.Rnw",     ## Cholesky decomposition',
+    '  "automaton.Rnw"     ## interpretation of automaton diagrams (using TikZ)',
     '))',
     ''),
     if(!("string" %in% type)) NULL else c(
     '## string exercises',
     'exams2html(c(',
-    '  "function.Rnw", ## names of R functions',
-    '  "countrycodes.Rnw"   ## three-letter ISO country codes',
+    '  "function.Rnw",     ## string question about R functions',
+    '  "countrycodes.Rnw"  ## string question about ISO country codes',
     '))',
     ''),
     if(!("cloze" %in% type)) NULL else c(
     '## cloze exercises (combining several num/schoice/mchoice/string parts)',
     'exams2html(c(',
-    '  "boxhist.Rnw",  ## download and describe artificial data (schoice/num)',
-    '  "confint2.Rnw", ## compute a confidence interval (num)',
-    '  "dist2.Rnw",    ## compute several types of distances (num)',
-    '  "fourfold.Rnw"  ## compute all elements of a fourfold table (num)',
+    '  "lm.Rnw",           ## simple linear regression (with CSV data, schoice/num)',
+    '  "boxhist.Rnw",      ## univariate exploration of a CSV file (schoice/num)',
+    '  "confint2.Rnw",     ## 2-sided confidence interval (num)',
+    '  "dist2.Rnw",        ## three distances in a Cartesian coordinate system (num)',
+    '  "fourfold.Rnw"      ## fourfold table (num)',
     '))',
     '',
     ''),
@@ -203,10 +221,14 @@ exams_skeleton <- exams.skeleton <- function(dir = ".",
     '##',
     '## - exams2html for customizable HTML output',
     '## - exams2moodle for Moodle XML that can be imported into Moodle quizzes',
+    '## - exams2blackboard for QTI 1.2 that can be imported into Blackboard and compatible systems',
     '## - exams2qti12/exams2qti21 for QTI XML (version 1.2 or 2.1) that can be imported',
     '##   into various learning management systems (e.g., OLAT or OpenOLAT among others)',
+    '## - exams2canvas for QTI 1.2 for Canvas (via exams2qti12/exams2qti21)',
+    '## - exams2openolat for QTI 2.1 (or 1.2) for OpenOLAT (via exams2qti12/exams2qti21)',
     '##',
-    '## - exams2arsnova for a JSON format that can be imported into ARSnova live quizzes ',
+    '## - exams2arsnova for a JSON format that can be imported into ARSnova live quizzes',
+    '## - exams2pandoc for customizable outputs in various formats (Docx, ODF, PDF, ...)',
     '',
     '## see the demo-*.R scripts in this directory for more examples',
     'dir()',
@@ -240,9 +262,12 @@ exams_skeleton <- exams.skeleton <- function(dir = ".",
     '## -> or customized via suitable templates',
     '',
     '## generate the HTML version of a single exercise (shown in browser)',
-    '## with default settings',
+    '## with default settings, using MathML',
     sprintf('exams2html("%s")', if(absolute) file.path(dir, "exercises", exrc[1L]) else file.path("exercises", exrc[1L])),
     '',
+    '## using MathJax (works in all browsers, including Chrome)',
+    sprintf('exams2html("%s", converter = "pandoc-mathjax")', if(absolute) file.path(dir, "exercises", exrc[1L]) else file.path("exercises", exrc[1L])),
+    '',
     '## generate a single HTML exam (shown in browser)',
     '## with specification of a template (the default) %s encoding',
     'exams2html(myexam, n = 1,',
@@ -366,7 +391,7 @@ exams_skeleton <- exams.skeleton <- function(dir = ".",
   )
 
   ## omit cloze exercises for exams2arsnova
-  exrc <- exrc[substr(exrc, 1, 7) != "boxhist"]
+  exrc <- exrc[substr(exrc, 1, 7) != "lm"]
   demo_exams[8L] <- sprintf('myexam <- c("%s")', paste(exrc, collapse = '", "'))
   
   demo_arsnova <- c(demo_exams,
